@@ -31,12 +31,13 @@
 #include <utp/utpserver.h>
 #include <version.h>
 
-#include <KDebug>
-#include <KLocale>
+#include "kget_debug.h"
+#include <QDebug>
+#include <KLocalizedString>
 #include <KIconLoader>
 #include <KIO/CopyJob>
 #include <KStandardDirs>
-#include <KUrl>
+#include <QUrl>
 #include <KMessageBox>
 
 #include <QFile>
@@ -49,18 +50,18 @@
 #endif
 
 BTTransfer::BTTransfer(TransferGroup* parent, TransferFactory* factory,
-               Scheduler* scheduler, const KUrl& src, const KUrl& dest,
+               Scheduler* scheduler, const QUrl &src, const QUrl& dest,
                const QDomElement * e)
   : Transfer(parent, factory, scheduler, src, dest, e),
-    torrent(0),
+    torrent(nullptr),
     m_tmp(KStandardDirs::locateLocal("appdata", "tmp/")),
     m_ready(false),
     m_downloadFinished(false),
     m_movingFile(false),
-    m_fileModel(0),
+    m_fileModel(nullptr),
     m_updateCounter(0)
 {
-    m_directory = m_dest.upUrl();//FIXME test
+    m_directory = KIO::upUrl(m_dest);//FIXME test
 
     setCapabilities(Transfer::Cap_Moving | Transfer::Cap_Renaming | Transfer::Cap_Resuming | Transfer::Cap_SpeedLimit);
 }
@@ -68,7 +69,7 @@ BTTransfer::BTTransfer(TransferGroup* parent, TransferFactory* factory,
 BTTransfer::~BTTransfer()
 {
     if (torrent && m_ready)
-        torrent->setMonitor(0);
+        torrent->setMonitor(nullptr);
 
     delete torrent;
 }
@@ -81,7 +82,7 @@ void BTTransfer::deinit(Transfer::DeleteOptions options)
     }
     if (options & Transfer::DeleteTemporaryFiles) {
         QDir tmpDir(m_tmp);
-        kDebug(5001) << m_tmp + m_source.fileName().remove(".torrent");
+        qCDebug(KGET_DEBUG) << m_tmp + m_source.fileName().remove(".torrent");
         tmpDir.rmdir(m_source.fileName().remove(".torrent") + "/dnd");
         tmpDir.cd(m_source.fileName().remove(".torrent"));
         QStringList list = tmpDir.entryList();
@@ -93,7 +94,7 @@ void BTTransfer::deinit(Transfer::DeleteOptions options)
 
         //only remove the .torrent file if it was downloaded by KGet
         if (!m_tmpTorrentFile.isEmpty()) {
-            kDebug(5001) << "Removing" << m_tmpTorrentFile;
+            qCDebug(KGET_DEBUG) << "Removing" << m_tmpTorrentFile;
             QFile torrentFile(m_tmpTorrentFile);
             torrentFile.remove();
         }
@@ -125,7 +126,7 @@ void BTTransfer::start()
     {
         if (!m_source.isLocalFile())
         {
-            kDebug(5001) << m_dest.path();
+            qCDebug(KGET_DEBUG) << m_dest.path();
             m_tmpTorrentFile = QString(KStandardDirs::locateLocal("appdata", "tmp/") + m_dest.fileName());
             Download *download = new Download(m_source, m_tmpTorrentFile);
 
@@ -133,7 +134,7 @@ void BTTransfer::start()
             setTransferChange(Tc_Status, true);
 
             //m_source = KStandardDirs::locateLocal("appdata", "tmp/") + m_source.fileName();
-            connect(download, SIGNAL(finishedSuccessfully(KUrl,QByteArray)), SLOT(btTransferInit(KUrl,QByteArray)));
+            connect(download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(btTransferInit(QUrl,QByteArray)));
         }
         else
             btTransferInit();
@@ -142,20 +143,22 @@ void BTTransfer::start()
         startTorrent();
 }
 
-bool BTTransfer::setDirectory(const KUrl &newDirectory)
+bool BTTransfer::setDirectory(const QUrl &newDirectory)
 {
     //check if the newDestination is the same as the old
-    KUrl temp = newDirectory;
-    temp.addPath(torrent->getStats().torrent_name);
+    QUrl temp = newDirectory;
+    temp = temp.adjusted(QUrl::StripTrailingSlash);
+    temp.setPath(temp.path() + '/' + (torrent->getStats().torrent_name));
     if (newDirectory.isValid() && (newDirectory != dest()) && (temp != dest()))
     {
-        if (torrent->changeOutputDir(newDirectory.pathOrUrl(), bt::TorrentInterface::MOVE_FILES))
+        if (torrent->changeOutputDir(newDirectory.url(QUrl::PreferLocalFile), bt::TorrentInterface::MOVE_FILES))
         {
             connect(torrent, SIGNAL(aboutToBeStarted(bt::TorrentInterface*,bool&)), this, SLOT(newDestResult()));
             m_movingFile = true;
             m_directory = newDirectory;
             m_dest = m_directory;
-            m_dest.addPath(torrent->getStats().torrent_name);
+            m_dest = m_dest.adjusted(QUrl::StripTrailingSlash);
+            m_dest.setPath(m_dest.path() + '/' + (torrent->getStats().torrent_name));
 
             setStatus(Job::Stopped, i18nc("changing the destination of the file", "Changing destination"), SmallIcon("media-playback-pause"));
             setTransferChange(Tc_Status, true);
@@ -219,7 +222,7 @@ void BTTransfer::load(const QDomElement *element)
 
 // void BTTransfer::save(const QDomElement &element)
 // {
-//     kDebug(5001);
+//     qCDebug(KGET_DEBUG);
 // 
 //     QDomElement e = element;
 // 
@@ -237,7 +240,7 @@ void BTTransfer::setPort(int port)
 
 void BTTransfer::setSpeedLimits(int ulLimit, int dlLimit)
 {
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
     if (!torrent)
         return;
 
@@ -246,14 +249,14 @@ void BTTransfer::setSpeedLimits(int ulLimit, int dlLimit)
 
 void BTTransfer::addTracker(const QString &url)
 {
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
     if(torrent->getStats().priv_torrent) {
-        KMessageBox::sorry(0, i18n("Cannot add a tracker to a private torrent."));
+        KMessageBox::sorry(nullptr, i18n("Cannot add a tracker to a private torrent."));
         return;
     }
 
-    if(!KUrl(url).isValid()) {
-       KMessageBox::error(0, i18n("Malformed URL."));
+    if(!QUrl(url).isValid()) {
+       KMessageBox::error(nullptr, i18n("Malformed URL."));
        return;
     }
 
@@ -266,7 +269,7 @@ void BTTransfer::startTorrent()
 {
     if (m_ready)
     {
-        //kDebug(5001) << "Going to download that stuff :-0";
+        //qCDebug(KGET_DEBUG) << "Going to download that stuff :-0";
         setSpeedLimits(uploadLimit(Transfer::InvisibleSpeedLimit), downloadLimit(Transfer::InvisibleSpeedLimit));//Set traffic-limits before starting
         torrent->setMonitor(this);
         torrent->start();
@@ -285,7 +288,7 @@ void BTTransfer::startTorrent()
 void BTTransfer::stopTorrent()
 {
     torrent->stop();
-    torrent->setMonitor(0);
+    torrent->setMonitor(nullptr);
     m_downloadSpeed = 0;
     timer.stop();
 
@@ -304,7 +307,7 @@ void BTTransfer::stopTorrent()
 
 void BTTransfer::updateTorrent()
 {
-    //kDebug(5001) << "Update torrent";
+    //qCDebug(KGET_DEBUG) << "Update torrent";
     bt::UpdateCurrentTime();
     bt::AuthenticationMonitor::instance().update();
     torrent->update();
@@ -353,8 +356,8 @@ void BTTransfer::updateFilesStatus()
     const bt::TorrentStats *stats = &torrent->getStats();
     if (stats->multi_file_torrent)
     {
-        QHash<KUrl, bt::TorrentFileInterface*>::const_iterator it;
-        QHash<KUrl, bt::TorrentFileInterface*>::const_iterator itEnd = m_files.constEnd();
+        QHash<QUrl, bt::TorrentFileInterface*>::const_iterator it;
+        QHash<QUrl, bt::TorrentFileInterface*>::const_iterator itEnd = m_files.constEnd();
         for (it = m_files.constBegin(); it != itEnd; ++it)
         {
             QModelIndex status = m_fileModel->index(it.key(), FileItem::Status);
@@ -399,10 +402,10 @@ void BTTransfer::updateFilesStatus()
     }
 }
 
-void BTTransfer::btTransferInit(const KUrl &src, const QByteArray &data)
+void BTTransfer::btTransferInit(const QUrl &src, const QByteArray &data)
 {
     Q_UNUSED(data)
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
     if (src != m_source && !src.isEmpty())
         m_source = src;
 
@@ -419,7 +422,7 @@ void BTTransfer::btTransferInit(const KUrl &src, const QByteArray &data)
 
     bt::InitLog(KStandardDirs::locateLocal("appdata", "torrentlog.log"), false, false);//initialize the torrent-log
 
-    bt::SetClientInfo("KGet", 2, KDE_VERSION_MINOR, KDE_VERSION_RELEASE, bt::NORMAL, "KG");//Set client info to KGet
+    bt::SetClientInfo("KGet", 2, 95, 0, bt::NORMAL, "KG");//Set client info to KGet TODO: don't hardcode version number
 
     bt::Uint16 i = 0;
     while (!bt::Globals::instance().initTCPServer(BittorrentSettings::port() + i) && i < 10)
@@ -452,12 +455,14 @@ void BTTransfer::btTransferInit(const KUrl &src, const QByteArray &data)
         m_ready = true;
 
         kDebug() << "Source:" << m_source.path() << "Destination:" << m_dest.path();
-        torrent->init(0, file.readAll(), m_tmp + m_source.fileName().remove(".torrent"), KUrl(m_dest.directory()).toLocalFile());
+        m_dest = m_dest.adjusted(QUrl::StripTrailingSlash);
+        torrent->init(nullptr, file.readAll(), m_tmp + m_source.fileName().remove(".torrent"), QUrl::fromLocalFile(m_dest.adjusted(QUrl::RemoveFilename).path()).toLocalFile());
 
         m_dest = torrent->getStats().output_path;
         if (!torrent->getStats().multi_file_torrent && (m_dest.fileName() != torrent->getStats().torrent_name))//TODO check if this is needed, so if that case is true at some point
         {
-            m_dest.addPath(torrent->getStats().torrent_name);
+            m_dest = m_dest.adjusted(QUrl::StripTrailingSlash);
+            m_dest.setPath(m_dest.path() + '/' + (torrent->getStats().torrent_name));
         }
 
         torrent->createFiles();
@@ -472,7 +477,7 @@ void BTTransfer::btTransferInit(const KUrl &src, const QByteArray &data)
     {
         m_ready = false;
         torrent->deleteLater();
-        torrent = 0;
+        torrent = nullptr;
         setError(err.toString(), SmallIcon("dialog-cancel"), Job::NotSolveable);
         setTransferChange(Tc_Status);
         return;
@@ -491,7 +496,7 @@ void BTTransfer::slotStoppedByError(const bt::TorrentInterface* &error, const QS
 
 void BTTransfer::slotDownloadFinished(bt::TorrentInterface* ti)
 {
-    kDebug(5001) << "Start seeding *********************************************************************";
+    qCDebug(KGET_DEBUG) << "Start seeding *********************************************************************";
     Q_UNUSED(ti)
     m_downloadFinished = true;
     //timer.stop();
@@ -500,12 +505,12 @@ void BTTransfer::slotDownloadFinished(bt::TorrentInterface* ti)
 }
 
 /**Property-Functions**/
-KUrl::List BTTransfer::trackersList() const
+QList<QUrl> BTTransfer::trackersList() const
 {
     if (!torrent)
-        return KUrl::List();
+        return QList<QUrl>();
 
-    KUrl::List trackers;
+    QList<QUrl> trackers;
     foreach (bt::TrackerInterface * tracker, torrent->getTrackersList()->getTrackers())
         trackers << tracker->trackerURL();
     return trackers;
@@ -661,9 +666,9 @@ void BTTransfer::destroyed()
         static_cast<BTTransferHandler*>(handler())->torrentMonitor()->destroyed();
 }
 
-QList<KUrl> BTTransfer::files() const
+QList<QUrl> BTTransfer::files() const
 {
-    QList<KUrl> urls;
+    QList<QUrl> urls;
 
     if (!torrent)
     {
@@ -676,16 +681,17 @@ QList<KUrl> BTTransfer::files() const
         for (uint i = 0; i < torrent->getNumFiles(); ++i)
         {
             const QString path = torrent->getTorrentFile(i).getPathOnDisk();
-            urls.append(KUrl(path));
+            urls.append(QUrl(path));
         }
     }
     //one single file
     else
     {
-        KUrl temp = m_dest;
+        QUrl temp = m_dest;
         if (m_dest.fileName() != torrent->getStats().torrent_name)//TODO check if the body is ever entered!
         {
-            temp.addPath(torrent->getStats().torrent_name);
+            temp = temp.adjusted(QUrl::StripTrailingSlash);
+            temp.setPath(temp.path() + '/' + (torrent->getStats().torrent_name));
         }
         urls.append(temp);
     }
@@ -718,7 +724,7 @@ void BTTransfer::filesSelected()
     {
         foreach (const QModelIndex &index, indexes)
         {
-            const KUrl dest = fileModel()->getUrl(index);
+            const QUrl dest = fileModel()->getUrl(index);
             const bool doDownload = index.data(Qt::CheckStateRole).toBool();
             bt::TorrentFileInterface *file = m_files[dest];
             file->setDoNotDownload(!doDownload);
@@ -743,15 +749,15 @@ FileModel *BTTransfer::fileModel()//TODO correct file model for one-file-torrent
             for (bt::Uint32 i = 0; i < torrent->getNumFiles(); ++i)
             {
                 bt::TorrentFileInterface *file = &torrent->getTorrentFile(i);
-                m_files[KUrl(file->getPathOnDisk())] = file;
+                m_files[QUrl(file->getPathOnDisk())] = file;
             }
             m_fileModel = new FileModel(m_files.keys(), directory(), this);
-    //         connect(m_fileModel, SIGNAL(rename(KUrl,KUrl)), this, SLOT(slotRename(KUrl,KUrl)));
+    //         connect(m_fileModel, SIGNAL(rename(QUrl,QUrl)), this, SLOT(slotRename(QUrl,QUrl)));
             connect(m_fileModel, SIGNAL(checkStateChanged()), this, SLOT(filesSelected()));
 
             //set the checkstate, the status and the size of the model items
-            QHash<KUrl, bt::TorrentFileInterface*>::const_iterator it;
-            QHash<KUrl, bt::TorrentFileInterface*>::const_iterator itEnd = m_files.constEnd();
+            QHash<QUrl, bt::TorrentFileInterface*>::const_iterator it;
+            QHash<QUrl, bt::TorrentFileInterface*>::const_iterator itEnd = m_files.constEnd();
             const Job::Status curentStatus = this->status();
             for (it = m_files.constBegin(); it != itEnd; ++it)
             {
@@ -781,17 +787,18 @@ FileModel *BTTransfer::fileModel()//TODO correct file model for one-file-torrent
         //one single file
         else
         {
-            QList<KUrl> urls;
-            KUrl temp = m_dest;
+            QList<QUrl> urls;
+            QUrl temp = m_dest;
             if (m_dest.fileName() != torrent->getStats().torrent_name)//TODO check if the body is ever entered!
             {
-                temp.addPath(torrent->getStats().torrent_name);
+                temp = temp.adjusted(QUrl::StripTrailingSlash);
+                temp.setPath(temp.path() + '/' + (torrent->getStats().torrent_name));
             }
-            const KUrl url = temp;
+            const QUrl url = temp;
             urls.append(url);
 
             m_fileModel = new FileModel(urls, directory(), this);
-            //         connect(m_fileModel, SIGNAL(rename(KUrl,KUrl)), this, SLOT(slotRename(KUrl,KUrl)));
+            //         connect(m_fileModel, SIGNAL(rename(QUrl,QUrl)), this, SLOT(slotRename(QUrl,QUrl)));
             connect(m_fileModel, SIGNAL(checkStateChanged()), this, SLOT(filesSelected()));
 
             QModelIndex size = m_fileModel->index(url, FileItem::Size);
@@ -819,4 +826,4 @@ FileModel *BTTransfer::fileModel()//TODO correct file model for one-file-torrent
     return m_fileModel;
 }
 
-#include "bttransfer.moc"
+
